{% extends 'ddm/admin/generic/page_with_form.html' %}
{% load static %}

{% block extrahead %}
<link rel="stylesheet" href="{% static 'ddm/css/bootstrap/bootstrap-table.min.css' %}">
<link rel="stylesheet" href="{% static 'ddm/css/bootstrap/bootstrap-table-filter-control.min.css' %}">
{% endblock %}

{% block scripts %}
{{ block.super }}
<script src="{% static 'ddm/js/filesaver/FileSaver.min.js' %}"></script>
<script src="{% static 'ddm/js/jquery/tableExport.min.js' %}"></script>
<script src="{% static 'ddm/js/bootstrap/bootstrap-table.min.js' %}"></script>
<script src="{% static 'ddm/js/bootstrap/bootstrap-table-filter-control.min.js' %}"></script>
<script src="{% static 'ddm/js/bootstrap/bootstrap-table-export.min.js' %}"></script>
{% endblock %}

{% block page_title %}Project Logs{% endblock %}

{% block main_heading %}Project Logs{% endblock %}

{% block main_body %}
{% include 'ddm/admin/project/project_logs/exception_log.html' %}

{% include 'ddm/admin/project/project_logs/event_log.html' %}

<div class="mt-3">
  <a href="{% url 'project-detail' project.pk %}">&#129040; go back</a>
</div>
{% endblock %}

{% block breadcrumbs %}
<a href="{% url 'project-list' %}">Projects</a> /
<a href="{% url 'project-detail' project.pk %}">"{{ project.name|truncatechars:15 }}" Project</a> /
Logs
{% endblock %}
