# Generated by Django 3.2.13 on 2024-03-13 15:12

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('ddm', '0046_donationblueprint_expected_fields_regex_matching'),
    ]

    operations = [
        migrations.AddField(
            model_name='fileuploader',
            name='combined_consent',
            field=models.BooleanField(default=False, help_text='If enabled, participants will be asked to consent to submit all uploaded data at once. Otherwise, participant will be asked to consent to the submission of the data separately for each blueprint.', verbose_name='All-in-one consent'),
        ),
    ]
