# Generated by Django 3.2.13 on 2022-09-22 14:40

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('ddm', '0013_auto_20220922_1324'),
    ]

    operations = [
        migrations.AddField(
            model_name='donationproject',
            name='redirect_enabled',
            field=models.BooleanField(default=False, verbose_name='Redirect enabled'),
        ),
        migrations.AddField(
            model_name='donationproject',
            name='redirect_target',
            field=models.CharField(blank=True, max_length=2000, null=True, verbose_name='Redirect target'),
        ),
    ]
