# Generated by Django 3.2.13 on 2023-02-17 14:52

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('ddm', '0034_auto_20230210_1148'),
    ]

    operations = [
        migrations.AddField(
            model_name='processingrule',
            name='replacement_value',
            field=models.TextField(blank=True),
        ),
        migrations.AlterField(
            model_name='processingrule',
            name='comparison_operator',
            field=models.CharField(blank=True, choices=[('==', 'Equal (==)'), ('!=', 'Not Equal (!=)'), ('>', 'Greater than (>)'), ('<', 'Smaller than (<)'), ('>=', 'Greater than or equal (>=)'), ('<=', 'Smaller than or equal (<=)'), ('regex-delete-match', 'Delete match (regex)'), ('regex-replace-match', 'Replace match (regex)'), ('regex-delete-row', 'Delete row when match (regex)')], default=None, max_length=24, null=True),
        ),
    ]
