# Generated by Django 3.2.13 on 2023-02-17 16:00

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('ddm', '0035_auto_20230217_1552'),
    ]

    operations = [
        migrations.AlterField(
            model_name='processingrule',
            name='replacement_value',
            field=models.TextField(blank=True, help_text='Only required for operation "Replace match (regex)".'),
        ),
    ]
