# Generated by Django 3.2.13 on 2022-12-12 20:21

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('ddm', '0018_auto_20220929_1308'),
    ]

    operations = [
        migrations.AddField(
            model_name='donationblueprint',
            name='csv_delimiter',
            field=models.CharField(blank=True, default='', max_length=10),
        ),
        migrations.AlterField(
            model_name='donationblueprint',
            name='exp_file_format',
            field=models.CharField(choices=[('json', 'Json Format'), ('csv', 'Csv Format')], default='json', max_length=10, verbose_name='Expected file format'),
        ),
        migrations.AlterField(
            model_name='processingrule',
            name='comparison_value',
            field=models.TextField(blank=True),
        ),
    ]
