# Generated by Django 3.2.13 on 2023-12-03 13:31

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('ddm', '0045_alter_processingrule_comparison_operator'),
    ]

    operations = [
        migrations.AddField(
            model_name='donationblueprint',
            name='expected_fields_regex_matching',
            field=models.BooleanField(default=False, help_text='Select if you use regex expressions in the "Excpected fields".'),
        ),
    ]
