# Generated by Django 3.2.13 on 2023-01-22 17:28

import ddm.models.core
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('ddm', '0030_auto_20230120_1746'),
    ]

    operations = [
        migrations.AlterField(
            model_name='donationproject',
            name='img_header_left',
            field=models.ImageField(blank=True, null=True, upload_to=ddm.models.core.project_header_dir_path, verbose_name='Header Image Left'),
        ),
        migrations.AlterField(
            model_name='donationproject',
            name='img_header_right',
            field=models.ImageField(blank=True, null=True, upload_to=ddm.models.core.project_header_dir_path, verbose_name='Header Image Right'),
        ),
    ]
