# Generated by Django 3.2.9 on 2022-05-02 16:10

import ckeditor.fields
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('ddm', '0003_auto_20220429_1154'),
    ]

    operations = [
        migrations.AlterField(
            model_name='donationblueprint',
            name='exp_file_format',
            field=models.CharField(choices=[('json', 'Json Format')], default='json', max_length=10, verbose_name='Expected File Format'),
        ),
        migrations.AlterField(
            model_name='donationproject',
            name='intro_text',
            field=ckeditor.fields.RichTextField(blank=True, null=True, verbose_name='Welcome Page Text'),
        ),
        migrations.AlterField(
            model_name='donationproject',
            name='outro_text',
            field=ckeditor.fields.RichTextField(blank=True, null=True, verbose_name='End Page Text'),
        ),
    ]
