#qapp{font-family:Avenir,Helvetica,Arial,sans-serif;-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale;text-align:left}.question-container{font-size:1rem;margin:0 20%;border-bottom:1px solid #d3d3d3;padding-bottom:50px;padding-top:50px}@media (max-width:992px){.question-container{margin:0}}.question-body{padding-left:30px;padding-right:30px}.flow-navigation{padding-top:50px;padding-right:20%}.required-but-missing{background:#ff480012!important;border-radius:5px}.required-hint{font-size:.9rem;color:#c51c00;padding-left:35px;display:none}.show{display:block!important}