# Generated by Django 3.2.13 on 2023-04-29 20:15

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('ddm', '0041_auto_20230429_1258'),
    ]

    operations = [
        migrations.AddField(
            model_name='questionbase',
            name='page',
            field=models.PositiveIntegerField(default=1, verbose_name='Page'),
        ),
        migrations.AlterField(
            model_name='questionbase',
            name='index',
            field=models.PositiveIntegerField(default=1, verbose_name='Index'),
        ),
    ]
