# Generated by Django 3.2.13 on 2022-09-22 11:24

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('ddm', '0012_auto_20220921_1634'),
    ]

    operations = [
        migrations.RenameModel(
            old_name='ZippedBlueprint',
            new_name='BlueprintContainer',
        ),
        migrations.RemoveConstraint(
            model_name='donationinstruction',
            name='unique_index_per_zipblueprint',
        ),
        migrations.RenameField(
            model_name='donationinstruction',
            old_name='zip_blueprint',
            new_name='blueprint_container',
        ),
        migrations.RemoveField(
            model_name='donationblueprint',
            name='zip_blueprint',
        ),
        migrations.AddField(
            model_name='donationblueprint',
            name='blueprint_container',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='ddm.blueprintcontainer', verbose_name='Blueprint container'),
        ),
        migrations.AddConstraint(
            model_name='donationinstruction',
            constraint=models.UniqueConstraint(fields=('index', 'blueprint_container'), name='unique_index_per_container'),
        ),
    ]
