# Generated by Django 3.2.13 on 2022-09-21 14:34

import ckeditor.fields
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('ddm', '0011_auto_20220830_1047'),
    ]

    operations = [
        migrations.AddField(
            model_name='donationproject',
            name='contact_information',
            field=ckeditor.fields.RichTextField(null=True, verbose_name='Contact information'),
        ),
        migrations.AddField(
            model_name='donationproject',
            name='data_protection_statement',
            field=ckeditor.fields.RichTextField(null=True, verbose_name='Data Protection Statement'),
        ),
    ]
