# Generated by Django 3.2.13 on 2022-06-21 09:36

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('ddm', '0006_auto_20220617_1433'),
    ]

    operations = [
        migrations.CreateModel(
            name='ResearchProfile',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('active', models.BooleanField(default=True)),
                ('created', models.DateTimeField(default=django.utils.timezone.now, verbose_name='date registered')),
                ('ignore_email_restriction', models.BooleanField(default=False)),
                ('api_key', models.CharField(blank=True, max_length=16, null=True, unique=True)),
                ('api_secret', models.CharField(blank=True, max_length=64, null=True)),
                ('user', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='ddm_research_profile', to=settings.AUTH_USER_MODEL)),
            ],
        ),
        migrations.AddField(
            model_name='donationproject',
            name='collaborators',
            field=models.ManyToManyField(related_name='project_collaborators', to='ddm.ResearchProfile'),
        ),
        migrations.AddField(
            model_name='donationproject',
            name='owner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='project_owner', to='ddm.researchprofile'),
        ),
    ]
