{% extends 'ddm/admin/generic/page_with_form.html' %}

{% block page_title %}Edit Project{% endblock %}

{% block main_heading %}Edit Debriefing Page of Project "{{ object.name }}"{% endblock %}

{% block submit_label %}Update Debriefing Page{% endblock %}

{% block cancel_target %}{% url 'project-detail' object.pk %}{% endblock %}

{% block breadcrumbs %}
<a href="{% url 'project-list' %}">Projects</a> /
<a href="{% url 'project-detail' object.pk %}">"{{ object.name|truncatechars:15 }}" Project</a> /
Edit Debriefing Page
{% endblock %}
