# Generated by Django 3.2.13 on 2023-02-10 10:48

import ckeditor_uploader.fields
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('ddm', '0033_participant_external_id'),
    ]

    operations = [
        migrations.AlterField(
            model_name='donationinstruction',
            name='text',
            field=ckeditor_uploader.fields.RichTextUploadingField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='donationproject',
            name='briefing_text',
            field=ckeditor_uploader.fields.RichTextUploadingField(blank=True, null=True, verbose_name='Welcome Page Text'),
        ),
        migrations.AlterField(
            model_name='donationproject',
            name='debriefing_text',
            field=ckeditor_uploader.fields.RichTextUploadingField(blank=True, null=True, verbose_name='End Page Text'),
        ),
        migrations.AlterField(
            model_name='questionbase',
            name='text',
            field=ckeditor_uploader.fields.RichTextUploadingField(blank=True, null=True),
        ),
    ]
