# Generated by Django 3.2.13 on 2023-03-09 08:26

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('ddm', '0038_auto_20230308_1619'),
    ]

    operations = [
        migrations.AlterField(
            model_name='donationblueprint',
            name='json_extraction_root',
            field=models.CharField(blank=True, default='', help_text="Indicates on which level of the files' data structure information should be extractet. If you want to extract information contained on the first level (e.g., {'field to be extracted': value}, you can leave this field empty. If you want to extract data located on a higher level, then you would provide the path to the parent field of the data you want to extract (e.g., if your json file is structured like this {'friends': {'real_friends': [{'name to extract': name, 'date to extract': date}], 'fake friends': [{'name': name, 'date': date }]}} and you want to extract the names and dates of real_friends, you would set the extraction root to 'friends.real_friends'.", max_length=200, verbose_name='Extraction Root'),
        ),
    ]
