# Generated by Django 3.2.13 on 2023-01-12 12:30

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('ddm', '0028_auto_20230112_1140'),
    ]

    operations = [
        migrations.RenameModel(
            old_name='EventLog',
            new_name='EventLogEntry',
        ),
    ]
