<p class="mt-0">
  When a file is uploaded, it is first validated following these steps:
</p>
<ol class="mb-2 mt-2">
  <li><span class="fs-08">[Only applies to ZIP uploads]</span> It is checked whether the uploaded ZIP container contains the expected file as specified in the <code>file path</code> setting.</li>
  <li>It is checked whether the uploaded file is in the <code>expected file format</code>.</li>
  <li>It is checked whether the identified file contains <i>all</i> <code>expected fields</code>.</li>
</ol>
<p class="mt-0">
  If any of these validation steps fail, no data is extracted and an exception message explaining what went wrong will be shown to the participant.
</p>
