# Generated by Django 3.2.13 on 2024-07-09 11:47

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('ddm', '0047_fileuploader_combined_consent'),
    ]

    operations = [
        migrations.AlterField(
            model_name='eventlogentry',
            name='description',
            field=models.TextField(),
        ),
    ]
