# Generated by Django 3.2.9 on 2022-05-03 08:59

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('ddm', '0004_auto_20220502_1810'),
    ]

    operations = [
        migrations.AlterField(
            model_name='donationproject',
            name='public_key',
            field=models.BinaryField(),
        ),
    ]
