# Generated by Django 3.2.13 on 2022-06-23 19:42

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('ddm', '0007_auto_20220621_1136'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='researchprofile',
            name='api_key',
        ),
        migrations.RemoveField(
            model_name='researchprofile',
            name='api_secret',
        ),
    ]
