# Generated by Django 3.2.13 on 2023-01-10 16:38

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('ddm', '0026_exceptionlogentry_raised_by'),
    ]

    operations = [
        migrations.AddField(
            model_name='exceptionlogentry',
            name='blueprint',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, to='ddm.donationblueprint'),
        ),
        migrations.AlterField(
            model_name='exceptionlogentry',
            name='exception_type',
            field=models.IntegerField(null=True),
        ),
    ]
