# Generated by Django 3.2.13 on 2023-02-27 10:17

import ckeditor_uploader.fields
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('ddm', '0036_alter_processingrule_replacement_value'),
    ]

    operations = [
        migrations.AddField(
            model_name='donationblueprint',
            name='description',
            field=models.TextField(null=True),
        ),
        migrations.AlterField(
            model_name='donationblueprint',
            name='exp_file_format',
            field=models.CharField(choices=[('json', 'JSON file'), ('csv', 'CSV file')], default='json', max_length=10, verbose_name='Expected file format'),
        ),
        migrations.AlterField(
            model_name='donationproject',
            name='briefing_text',
            field=ckeditor_uploader.fields.RichTextUploadingField(blank=True, null=True, verbose_name='Briefing Text'),
        ),
        migrations.AlterField(
            model_name='donationproject',
            name='debriefing_text',
            field=ckeditor_uploader.fields.RichTextUploadingField(blank=True, null=True, verbose_name='Debriefing Text'),
        ),
    ]
