# Generated by Django 3.2.13 on 2023-04-27 15:36

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('ddm', '0039_alter_donationblueprint_json_extraction_root'),
    ]

    operations = [
        migrations.AddField(
            model_name='participant',
            name='current_step',
            field=models.IntegerField(blank=True, null=True),
        ),
    ]
